@@ -297,11 +297,14 @@ class DynamicSetting(object):
         self.download_try_time = self.current_time
 
         try:
-            if self.redis_client.set_download_in_progress(
-                    keys=[self.download_in_progress_key],
-                    args=[self.download_in_progress_ttl]
-            ) is None:
+            t = self.redis_client.set_download_in_progress(
+                keys=[self.download_in_progress_key],
+                args=[self.download_in_progress_ttl]
+            )
+            print(t)
+            if t == b'0':
                 return True
+            return False
         except (redis.exceptions.TimeoutError, redis.exceptions.ConnectionError):
             return False
 
@@ -310,6 +313,7 @@ class DynamicSetting(object):
         if self.download_in_progress():
             if self.verbose:
                 print(f'{self.slug} - Download already in progress')
+            return
 
         try:
             if self.verbose:
